/*
 * Copyright (c) 2002-2014, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.calendar.modules.ical;

import fr.paris.lutece.plugins.calendar.business.Agenda;
import fr.paris.lutece.plugins.calendar.service.AgendaLoader;
import fr.paris.lutece.portal.service.util.AppLogService;
import fr.paris.lutece.portal.service.util.AppPathService;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import net.fortuna.ical4j.data.CalendarBuilder;
import net.fortuna.ical4j.data.ParserException;
import net.fortuna.ical4j.model.Calendar;


/**
 * This class is an implementation of an AgendaLoader that load agenda using
 * the iCalendar (RFC 2445).
 */
public class ICalAgendaLoader implements AgendaLoader
{
    /**
     * Implementation of the load
     * @param strParameter The parameter string (here a "*.ics" file location)
     * @return An agenda object
     */
    public Agenda load( String strParameter )
    {
        Agenda agenda = null;
        String strFile = AppPathService.getWebAppPath( ) + strParameter;
        FileInputStream fis = null;
        try
        {
            fis = new FileInputStream( strFile );
            CalendarBuilder builder = new CalendarBuilder( );
            Calendar calendar = builder.build( fis );
            ICalAgenda a = new ICalAgenda( );
            a.setEvents( calendar );
            agenda = a;
        }
        catch ( ParserException e )
        {
            AppLogService.error( e.getMessage( ), e );
        }
        catch ( FileNotFoundException e )
        {
            AppLogService.error( e.getMessage( ), e );
        }
        catch ( IOException e )
        {
            AppLogService.error( e.getMessage( ), e );
        }
        finally
        {
            try
            {
                fis.close( );
            }
            catch ( IOException e )
            {
                AppLogService.error( e.getMessage( ), e );
            }
        }

        return agenda;
    }
}
